==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/SetSequenceOriginDialogFiller.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include <QApplication>

#include <primitives/GTSpinBox.h>
#include <primitives/GTWidget.h>

#include "SetSequenceOriginDialogFiller.h"

namespace U2 {

#define GT_CLASS_NAME "SetSequenceOriginDialogFiller"
#define GT_METHOD_NAME "run"

void SetSequenceOriginDialogFiller::commonScenario(){
    QWidget *dialog = QApplication::activeModalWidget();
    GT_CHECK(dialog != NULL, "dialog not found");

    QSpinBox* seqOriginBox = GTWidget::findExactWidget<QSpinBox*>(os, "seqOriginBox", dialog);
    GTSpinBox::setValue(os, seqOriginBox, start, GTGlobals::UseKeyBoard);

    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
}

#undef GT_METHOD_NAME
#undef GT_CLASS_NAME

}

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/SetSequenceOriginDialogFiller.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include <primitives/GTSpinBox.h>
#include <primitives/GTWidget.h>

#include <QApplication>

#include "SetSequenceOriginDialogFiller.h"

namespace U2 {

#define GT_CLASS_NAME "SetSequenceOriginDialogFiller"
#define GT_METHOD_NAME "run"

void SetSequenceOriginDialogFiller::commonScenario() {
    QWidget *dialog = QApplication::activeModalWidget();
    GT_CHECK(dialog != nullptr, "dialog not found");

    QSpinBox *seqOriginBox = GTWidget::findExactWidget<QSpinBox *>(os, "seqOriginBox", dialog);
    GTSpinBox::setValue(os, seqOriginBox, start, GTGlobals::UseKeyBoard);

    GTUtilsDialog::clickButtonBox(os, dialog, QDialogButtonBox::Ok);
}

#undef GT_METHOD_NAME
#undef GT_CLASS_NAME

}  // namespace U2
